@@ -16,7 +16,7 @@ from .practice import (
     validate_tillage_site_type, validate_tillage_values
 )
 from .product import (
-    validate_economicValueShare, validate_value as validate_product_value, validate_excreta,
+    validate_economicValueShare, validate_value_empty, validate_value_0, validate_excreta,
     validate_primary as validate_product_primary
 )
 from .data_completeness import validate_dataCompleteness
@@ -209,7 +209,8 @@ def validate_cycle(cycle: dict, node_map: dict = {}):
         validate_list_term_percent(cycle, 'products'),
         validate_economicValueShare(cycle.get('products')),
         validate_sum_aboveGroundCropResidue(cycle.get('products')),
-        validate_product_value(cycle.get('products')),
+        validate_value_empty(cycle.get('products')),
+        validate_value_0(cycle.get('products')),
         validate_product_primary(cycle.get('products')),
         validate_properties_default_value(cycle, 'products'),
         validate_properties_valueType(cycle, 'products'),
