@@ -52,7 +52,8 @@ def _practice_is_tillage(practice: dict):
 
 
 def validate_no_tillage(practices: list):
-    no_value = list_sum(find_term_match(practices, NO_TILLAGE_ID).get('value', [100]), 100)
+    no_tillage = find_term_match(practices, NO_TILLAGE_ID, None)
+    no_value = list_sum(no_tillage.get('value', [100]), 100) if no_tillage else 0
     return _filter_list_errors([{
         'level': 'error',
         'dataPath': f".practices[{index}]",
@@ -83,7 +84,6 @@ def validate_tillage_site_type(practices: list, site: dict):
 
 
 def _validate_tillage_with_values(practices: list):
-    practices = list(filter(_unique_practice, practices))
     sum_values = sum(map(lambda p: list_sum(p.get('value', [])), practices))
     return 99.5 < sum_values < 100.5 or {
         'level': 'error',
@@ -93,8 +93,7 @@ def _validate_tillage_with_values(practices: list):
 
 
 def _validate_tillage_no_values(practices: list):
-    practices = list(filter(_unique_practice, practices))
-    return len(practices) == 1 or {
+    return len(practices) <= 1 or {
         'level': 'error',
         'dataPath': '.practices',
         'message': 'can only have 1 tillage practice without a value',
@@ -105,7 +104,7 @@ def _validate_tillage_no_values(practices: list):
 
 
 def validate_tillage_values(practices: list):
-    practices = filter_list_term_type(practices, TermTermType.TILLAGE)
+    practices = list(filter(_unique_practice, practices))
     with_value = list(filter(lambda p: len(p.get('value', [])) > 0, practices))
     no_value = list(filter(lambda p: len(p.get('value', [])) == 0, practices))
     return {
