@@ -39,8 +39,8 @@ def validate_value_0(products: list):
         return value != 0 or _filter_list_errors([
             eva == 0 or {
                 'level': 'error',
-                'dataPath': f".products[{index}].economicValueShare",
-                'message': 'must be 0 for product value 0',
+                'dataPath': f".products[{index}].value",
+                'message': 'economicValueShare must be 0 for product value 0',
                 'params': {
                     'value': eva,
                     'term': product.get('term')
@@ -48,8 +48,8 @@ def validate_value_0(products: list):
             },
             revenue == 0 or {
                 'level': 'error',
-                'dataPath': f".products[{index}].revenue",
-                'message': 'must be 0 for product value 0',
+                'dataPath': f".products[{index}].value",
+                'message': 'revenue must be 0 for product value 0',
                 'params': {
                     'value': revenue,
                     'term': product.get('term')
