@@ -253,9 +253,21 @@ def validate_area_size(node: dict):
     }
 
 
+def need_validate_boundary_size(node: dict):
+    return all([
+        is_enabled(),
+        not need_validate_coordinates(node),
+        'boundary' in node
+    ])
+
+
 def validate_boundary_size(node: dict):
     boundary = node.get('boundary')
-    area = get_boundary_size(boundary) if boundary else 0
+    try:
+        # get_boundary_size might throw error is geometry has too many edges
+        area = get_boundary_size(boundary) if boundary else 0
+    except Exception:
+        area = 0
     return area < MAX_AREA_SIZE or {
         'level': 'warning',
         'dataPath': '.boundary',
@@ -267,10 +279,23 @@ def validate_boundary_size(node: dict):
     }
 
 
+def need_validate_region_size(node: dict):
+    return all([
+        is_enabled(),
+        not need_validate_coordinates(node),
+        not need_validate_boundary_size(node),
+        'region' in node or 'country' in node
+    ])
+
+
 def validate_region_size(node: dict):
     region_id = node.get('region', node.get('country', {})).get('@id')
     region = download_hestia(region_id) if region_id else {}
-    area = region.get('area', get_region_size(region_id) if region_id else None) or 0
+    try:
+        # get_region_size might throw error is geometry has too many edges
+        area = region.get('area', get_region_size(region_id) if region_id else None) or 0
+    except Exception:
+        area = 0
     return area < MAX_AREA_SIZE or {
         'level': 'warning',
         'dataPath': f".{'region' if node.get('region') else 'country'}",
