@@ -1,12 +1,13 @@
 from hestia_earth.schema import SiteSiteType
 from hestia_earth.utils.tools import flatten
 
-from hestia_earth.validation.gee import is_enabled, fetch_data
+from hestia_earth.validation.gee import fetch_data
 from .shared import (
-    validate_boundary_size, validate_dates, validate_list_dates, validate_list_dates_format, validate_list_min_max,
+    validate_dates, validate_list_dates, validate_list_dates_format, validate_list_min_max,
     validate_region_in_country, validate_country, validate_is_region, validate_coordinates, need_validate_coordinates,
     validate_area, need_validate_area, validate_list_term_percent, validate_linked_source_privacy,
-    validate_list_date_lt_today, validate_date_lt_today, validate_area_size, validate_region_size
+    validate_list_date_lt_today, validate_date_lt_today, validate_area_size,
+    validate_region_size, need_validate_region_size, validate_boundary_size, need_validate_boundary_size
 )
 from .infrastructure import validate_lifespan
 from .measurement import (
@@ -104,8 +105,8 @@ def validate_site(site: dict, node_map: dict = {}):
         validate_coordinates(site) if validate_site_coordinates(site) else True,
         validate_area(site) if need_validate_area(site) else True,
         validate_area_size(site),
-        validate_region_size(site) if is_enabled() else True,
-        validate_boundary_size(site) if is_enabled() else True
+        validate_boundary_size(site) if need_validate_boundary_size(site) else True,
+        validate_region_size(site) if need_validate_region_size(site) else True
     ] + flatten([
         validate_list_dates(site, 'measurements'),
         validate_list_dates_format(site, 'measurements'),
