@@ -62,8 +62,8 @@ def test_validate_value_0_error():
     assert validate_value_0(data.get('nodes')) == [
         {
             'level': 'error',
-            'dataPath': '.products[1].economicValueShare',
-            'message': 'must be 0 for product value 0',
+            'dataPath': '.products[1].value',
+            'message': 'economicValueShare must be 0 for product value 0',
             'params': {
                 'value': None,
                 'term': {
@@ -75,8 +75,8 @@ def test_validate_value_0_error():
         },
         {
             'level': 'error',
-            'dataPath': '.products[1].revenue',
-            'message': 'must be 0 for product value 0',
+            'dataPath': '.products[1].value',
+            'message': 'revenue must be 0 for product value 0',
             'params': {
                 'value': 100,
                 'term': {
