@@ -10,7 +10,7 @@ from hestia_earth.validation.validators.shared import (
     validate_list_dates_length, validate_date_lt_today, validate_list_date_lt_today,
     value_difference, is_value_different, validate_list_model, validate_list_model_config,
     validate_properties_same_length, validate_list_duplicate_values, validate_nodes_duplicates, validate_area_size,
-    validate_boundary_size, validate_region_size
+    validate_boundary_size, need_validate_boundary_size, validate_region_size, need_validate_region_size
 )
 from hestia_earth.validation.validators.cycle import PRODUCTS_MODEL_CONFIG
 
@@ -269,9 +269,10 @@ def test_validate_coordinates_invalid(*args):
     }
 
 
-def test_need_validate_coordinates():
+@patch(f"{class_path}.is_enabled", return_value=True)
+def test_need_validate_coordinates(*args):
     node = {}
-    assert not need_validate_coordinates(node) is True
+    assert not need_validate_coordinates(node)
 
     node['latitude'] = 0
     node['longitude'] = 0
@@ -675,6 +676,19 @@ def test_validate_area_size_warning():
     }
 
 
+@patch(f"{class_path}.is_enabled", return_value=True)
+def test_need_validate_boundary_size(*args):
+    node = {}
+    assert not need_validate_boundary_size(node)
+
+    node['boundary'] = 10
+    assert need_validate_boundary_size(node) is True
+
+    node['latitude'] = 10
+    node['longitude'] = 10
+    assert not need_validate_boundary_size(node)
+
+
 @patch(f"{class_path}.get_boundary_size", return_value=2500)
 def test_validate_boundary_size_valid(*args):
     # no boundary => valid
@@ -696,6 +710,19 @@ def test_validate_boundary_size_warning(*args):
     }
 
 
+@patch(f"{class_path}.is_enabled", return_value=True)
+def test_need_validate_region_size(*args):
+    node = {}
+    assert not need_validate_region_size(node)
+
+    node['region'] = 'GADM'
+    assert need_validate_region_size(node) is True
+
+    node['latitude'] = 10
+    node['longitude'] = 10
+    assert not need_validate_region_size(node)
+
+
 @patch(f"{class_path}.get_region_size", return_value=2500)
 @patch(f"{class_path}.download_hestia")
 def test_validate_region_size_valid(mock_download, *args):
